@@ -10,7 +10,7 @@ use Data::TableReader::Iterator;
 use namespace::clean;
 
 # ABSTRACT: Extract records from "dirty" tabular data sources
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 
 has input               => ( is => 'rw', required => 1 );
@@ -144,6 +144,7 @@ sub _coerce_field_list {
 			$_= Data::TableReader::Field->new(\%args)
 		} else {
 			croak "Can't coerce '$_' to a Field object"
+				unless blessed($_) && $_->isa('Data::TableReader::Field');
 		}
 	}
 	return \@list;
@@ -353,6 +354,7 @@ sub _find_table {
 		my $col_map= [ $self->has_col_map? @{$self->col_map} : @fields ];
 		$result{found}= {
 			row_idx => -1,
+			row => undef,
 			dataset_idx => 0,
 			col_map => $col_map,
 			messages => [],
@@ -379,9 +381,10 @@ sub _find_table {
 		
 		# Scan through the rows of the dataset up to the end of header_row_at, accumulating rows so that
 		# multi-line regexes can match.
-		for ($start .. $end) {
+		for my $row ($start .. $end) {
 			my %attempt= (
-				row_idx => $_,
+				row_idx => $row-1,
+				row => $row,
 				dataset_idx => $dataset_idx,
 				messages => []
 			);
@@ -984,7 +987,7 @@ Data::TableReader - Extract records from "dirty" tabular data sources
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -1145,8 +1148,8 @@ This is the output of the most recent L</find_table> operation.
 
   {
     candidates => [
-      { row_idx => $n,
-        dataset_idx => $n,
+      { dataset_idx => $n,
+        row => $n,
         col_map => [ $field_or_undef, $field_or_undef, ... ],
         missing_required => \@fields,
         ambiguous_columns => { $col_idx => \@fields, ... },
