@@ -7,7 +7,7 @@ require MRO::Compat if $] < '5.010';
 extends 'Data::TableReader::Decoder';
 
 # ABSTRACT: Decoder that returns supplied data without decoding anything
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.021'; # VERSION
 
 
 sub BUILDARGS {
@@ -38,7 +38,6 @@ sub iterator {
 	my $self= shift;
 	my $data= $self->datasets;
 	my $table= $data->[0];
-	my $colmax= $table? scalar(@{$table->[0]})-1 : -1;
 	my $rowmax= $table? $#$table : -1;
 	my $row= -1;
 	Data::TableReader::Decoder::Mock::_Iter->new(
@@ -54,7 +53,6 @@ sub iterator {
 			table_idx => 0,
 			table_ref => \$table,
 			row_ref => \$row,
-			colmax_ref => \$colmax,
 			rowmax_ref => \$rowmax,
 			origin => [ 0, $row ],
 		}
@@ -95,13 +93,11 @@ sub Data::TableReader::Decoder::Mock::_Iter::seek {
 	$to ||= $f->{origin};
 	my ($table_idx, $row)= @$to;
 	my $table= $f->{data}[$table_idx];
-	my $colmax= $table? scalar(@{$table->[0]})-1 : -1;
 	my $rowmax= $table? $#$table : -1;
 	$row= -1 unless defined $row;
 	$f->{table_idx}= $table_idx;
 	${$f->{table_ref}}= $table;
 	${$f->{row_ref}}= $row;
-	${$f->{colmax_ref}}= $colmax;
 	${$f->{rowmax_ref}}= $rowmax;
 	1;
 }
@@ -127,7 +123,7 @@ Data::TableReader::Decoder::Mock - Decoder that returns supplied data without de
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
